import React, { useEffect, useState } from "react";
import { Card, Col, Container, Row, Button } from "react-bootstrap";
import { Link } from "react-router-dom";
import CategoryDataAccess from "dataAccess/categoryDataAccess";
import { connect, useDispatch } from "react-redux";
import { actions as categoryActions } from "@redux/categoryRedux";
import SpinnerLocal from "../spinner";

const ViewAllSubCategory = (props: any) => {

    const categorySlug = props.match.params.categorySlug;
    const dispatch = useDispatch();
    let page;

    useEffect(() => {
        dispatch(categoryActions.getAllSubCategories(categorySlug));
    }, [dispatch, categorySlug]);

  if (props.category.allSubCategoryLoading && props.category.allSubCategory.length === 0) {
    return <SpinnerLocal height="75vh"/>;
  }
  return (
    <div className="new-category-design">
      <Container fluid>
        <Row className="top border-bottom">
          <Col xl={4} lg={4} md={12} sm={12} xs={12}>
              <h4 className="top-title"> { categorySlug.split('-').map(slag => <span className="text-capitalize">{slag} </span>) } </h4>
          </Col>
        </Row>
        <Row className="responsive-card">
            {!props.category.allSubCategoryLoading && props.category.allSubCategory.length === 0 && (
                <div className="w-100 d-flex justify-content-center align-items-center" style={{height: "50vh", fontSize: 34}}>
                    No Subcategories found
                </div>
            )}

          {props.category.allSubCategory.length !== 0 &&
            props.category.allSubCategory.map((category) => {
              return (
                  <Col xl={2} lg={3} md={4} sm={9} xs={10}>
                    <Link
                      to={"/productsByCategory/" + category.slug}
                      className="offer-image-link">
                        <Card className="card-offer">
                        {category.image==null ? (
                          <img
                            src="/images/health.png"
                            className="offer-image"
                            alt=""
                            style={{ margin:"auto", width:"50px", height:"50px", marginTop:"30px", marginBottom:"20px", }}
                          />
                        ) : (
                          <img
                            src={category.image}
                            className="offer-image"
                            alt=""
                            style={{ margin:"auto", width:"50px", height:"50px", marginTop:"30px", marginBottom:"20px", }}
                          />
                           
                        )}
                          
                          <Card.Body>
                            <Card.Title className="offer-card-title">
                              {category.name.length > 20 ? (
                                <p className="card-product-name">
                                  {category.name.substring(0, 22) + "..."}
                                </p>
                              ) : (
                                <p className="card-product-name">{category.name}</p>
                              )}
                            </Card.Title>
                          </Card.Body>
                        </Card>
                    </Link>
                  </Col>
              );
            })}


            {!props.category.allSubCategoryLoading &&
              props.category.allSubCategoryInfo.last_page &&
              props.category.allSubCategoryInfo.current_page !==
                props.category.allSubCategoryInfo.last_page && (
                <Row style={{ textAlign: "center", marginTop: "20px" }}>
                  <Col>
                    <Button
                      className="load-more"
                      variant="primary"
                      onClick={() => {
                        dispatch(categoryActions.getAllSubCategories(categorySlug, props.category.allSubCategoryInfo.current_page + 1));
                      }}
                    >
                      <span className="btn-text">Load more</span>
                    </Button>
                  </Col>
                </Row>
              )}

            {/*  Loading... */}
            {(props.category.allSubCategoryLoading && props.category.allSubCategory.length > 0) && (
                <SpinnerLocal height="15vh"/>
            )}
        </Row>
      </Container>
    </div>
  );
};

const mapStateToProps = ({ category }) => { return { category }; };
export default connect(mapStateToProps)(ViewAllSubCategory);